VMError

Enum VMError 

pub enum VMError {
    FunctionCallError(FunctionCallError),
    ExternalError(Vec<u8>),
    InconsistentStateError(InconsistentStateError),
    CacheError(CacheError),
}

Variants



FunctionCallError(FunctionCallError)



ExternalError(Vec<u8>)

Serialized external error from External trait implementation.



InconsistentStateError(InconsistentStateError)

An error that is caused by an operation on an inconsistent state. E.g. an integer overflow by using a value from the given context.



CacheError(CacheError)

Error caused by caching.